@@ -73,6 +73,15 @@ def dispatch(host: CPanelEndpoint, args: List[str]) -> str:
 		elif cmd_is(cmd, "get stat"):
 			r = host.dump(lambda: uapi.StatsBar.get_stats(display = "|".join(args[2:])))
 
+		elif cmd_is(cmd, "get ssh port"):
+			r = host.dump(lambda: uapi.SSH.get_port())
+
+		elif cmd_is(cmd, "block ip"):
+			r = host.check(lambda: uapi.BlockIP.add_ip(ip = args[2]))
+
+		elif cmd_is(cmd, "unblock ip"):
+			r = host.check(lambda: uapi.BlockIP.remove_ip(ip = args[2]))
+
 		elif cmd_is(cmd, "list account"):
 			r = host.dump(lambda: uapi.Resellers.list_accounts())
 
@@ -91,6 +100,9 @@ def dispatch(host: CPanelEndpoint, args: List[str]) -> str:
 		elif cmd_is(cmd, "list backup"):
 			r = host.dump(lambda: uapi.Backup.list_backups())
 
+		elif cmd_is(cmd, "restore backup"):
+			r = host.check(lambda: uapi.Backup.restore_files(backup = args[2]))
+
 		elif cmd_is(cmd, "update cache"):
 			r = host.dump(lambda: uapi.CacheBuster.update())
 
@@ -324,6 +336,49 @@ def dispatch(host: CPanelEndpoint, args: List[str]) -> str:
 		elif cmd_is(cmd, "list webmail app"):
 			r = host.dump(lambda: uapi.WebmailApps.list_webmail_apps())
 
+		elif cmd_is(cmd, "add mailman list"):
+			private: int = 1 if len(args) > 5 and args[5].lower() == "private" else 0
+			r = host.check(lambda: uapi.Email.add_list(
+				domain = domain(args[3]), list = username(args[3]), password = args[4], private = private))
+
+		elif cmd_is(cmd, "delete mailman list"):
+			r = host.check(lambda: uapi.Email.delete_list(list = args[3]))
+
+		elif cmd_is(cmd, "count mailman list"):
+			r = host.dump(lambda: uapi.Email.count_lists())
+
+		elif cmd_is(cmd, "list mailman list"):
+			r = host.dump(lambda: uapi.Email.list_lists())
+
+		elif cmd_is(cmd, "add mailman delegate"):
+			r = host.check(lambda: uapi.Email.add_mailman_delegates(list = args[3], delegates = ','.join(args[4:])))
+
+		elif cmd_is(cmd, "delete mailman delegate", "rm mailman delegate", "remove mailman delegate"):
+			r = host.check(lambda: uapi.Email.remove_mailman_delegates(list = args[3], delegates = ','.join(args[4:])))
+
+		elif cmd_is(cmd, "list mailman delegate"):
+			r = host.dump(lambda: uapi.Email.get_mailman_delegates(list= args[3]))
+
+		elif cmd_is(cmd, "check mailman delegate"):
+			r = host.dump(lambda: uapi.Email.has_delegated_mailman_lists(delegate = args[3]))
+
+		elif cmd_is(cmd, "generate mailman password"):
+			r = host.dump(lambda: uapi.Email.generate_mailman_otp(list = args[3]))
+
+		elif cmd_is(cmd, "set mailman password"):
+			r = host.check(lambda: uapi.Email.passwd_list(list = args[3], password = args[4]))
+
+		elif cmd_is(cmd, "get mailman usage"):
+			r = host.dump(lambda: uapi.Email.get_lists_total_disk_usage())
+
+		elif cmd_is(cmd, "set mailman private"):
+			r = host.check(lambda: uapi.Email.set_list_privacy_options(
+				list = args[3], advertised = 0, archive_private = 1, subscribe_policy = 3))
+
+		elif cmd_is(cmd, "set mailman public"):
+			r = host.check(lambda: uapi.Email.set_list_privacy_options(
+				list = args[3], advertised = 1, archive_private = 0, subscribe_policy = 1))
+
 		elif cmd_is(cmd, "create ftp"):
 			homedir: str = username(args[2]) + '_ftp'
 			if len(args) > 5:
